@@ -3,7 +3,7 @@
 import functools
 import gevent
 import kola
-from kola.utils import safe_call
+from kola import safe_call
 
 
 class Blueprint(kola.Blueprint):
