@@ -1,9 +1,7 @@
 # -*- coding: utf-8 -*-
 
 import socket
-import errno
-from kola.utils import safe_call
-from kola.vals import logger
+from kola import safe_call, logger
 
 
 class GStream(object):
